/*-------------------------------------------------------------------------
 *
 * pg_autovacuum.h
 *	  definition of the system "autovacuum" relation (pg_autovacuum)
 *
 * NOTE: an object is identified by the OID of the row that primarily
 * defines the object, plus the OID of the table that that row appears in.
 * For example, a function is identified by the OID of its pg_proc row
 * plus the pg_class OID of table pg_proc.	This allows unique identification
 * of objects without assuming that OIDs are unique across tables.
 *
 * Since attributes don't have OIDs of their own, we identify an attribute
 * comment by the objoid+classoid of its parent table, plus an "objsubid"
 * giving the attribute column number.	"objsubid" must be zero in a comment
 * for a table itself, so that it is distinct from any column comment.
 * Currently, objsubid is unused and zero for all other kinds of objects,
 * but perhaps it might be useful someday to associate comments with
 * constituent elements of other kinds of objects (arguments of a function,
 * for example).
 *
 *
 * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * $PostgreSQL: pgsql-server/src/include/catalog/pg_autovacuum.h,v 1.20 2003/11/29 22:40:58 pgsql Exp $
 *
 * NOTES
 *		the genbki.sh script reads this file and generates .bki
 *		information from the DATA() statements.
 *
 *		XXX do NOT break up DATA() statements into multiple lines!
 *			the scripts are not as smart as you might think...
 *
 *-------------------------------------------------------------------------
 */
#ifndef PG_AUTOVACUUM_H
#define PG_AUTOVACUUM_H

/* ----------------
 *		postgres.h contains the system type definitions and the
 *		CATALOG(), BOOTSTRAP and DATA() sugar words so this file
 *		can be read by both genbki.sh and the C compiler.
 * ----------------
 */

/* ----------------
 *		pg_autovacuum definition.	cpp turns this into
 *		typedef struct FormData_pg_autovacuum
 * ----------------
 */
CATALOG(pg_autovacuum) BKI_WITHOUT_OIDS
{
	Oid			table_oid;		/* OID of table */
	int4		analyze_base_threshold; /* Base Threshold value */
	float4		vacuum_base_threshold;  /* Base Threshold value */
	int4		analyze_scaling_factor; /* Threshold of ins/upd/del's before analyze */
	float4		vacuum_scaling_factor;  /* Threshold of ins/upd/del's before vacuuum */
	int8		analyze_threshold; /* Threshold of ins/upd/del's before analyze */
	int8		vacuum_threshold;  /* Threshold of ins/upd/del's before vacuuum */
	int8		cnt_at_last_analyze;		/* equal to: inserts + updates as
										 * of the last analyze or initial
										 * values at startup */
	int8		cnt_at_last_vacuum;		/* equal to: deletes + updates as
										 * of the last vacuum or initial
										 * values at startup */
} FormData_pg_autovacuum;

/* ----------------
 *		Form_pg_autovacuum corresponds to a pointer to a tuple with
 *		the format of pg_autovacuum relation.
 * ----------------
 */
typedef FormData_pg_autovacuum *Form_pg_autovacuum;

/* ----------------
 *		compiler constants for pg_autovacuum
 * ----------------
 */
#define Natts_pg_autovacuum				9
#define Anum_pg_autovacuum_table_oid	1
#define Anum_pg_autovacuum_analyze_base_threshold		2
#define Anum_pg_autovacuum_vacuum_base_threshold		3
#define Anum_pg_autovacuum_analyze_scaling_factor		4
#define Anum_pg_autovacuum_vacuum_scaling_factor	5
#define Anum_pg_autovacuum_analyze_threshold		6
#define Anum_pg_autovacuum_vacuum_threshold		7
#define Anum_pg_autovacuum_cnt_at_last_analyze 	8
#define Anum_pg_autovacuum_cnt_at_last_vacuum 	9

/* ----------------
 *		initial contents of pg_autovacuum
 * ----------------
 */

/*
 *	Because the contents of this table are taken from the other *.h files,
 *	there is no initialization here.  The initial contents are extracted
 *	by genbki.sh and loaded during initdb.
 */

#endif   /* PG_AUTOVACUUM_H */
